import { RouteMatcher } from "./route-matcher";
export class AppPageInterceptingRouteMatcher extends RouteMatcher {
    constructor(definition){
        super(definition);
        this.interceptingRouteMatcher = new RouteMatcher({
            ...definition,
            pathname: definition.interceptingRoute
        });
    }
    get identity() {
        // TODO: probably include other details about the entrypoint
        return `${this.definition.pathname}?__nextPage=${this.definition.page}`;
    }
    /**
   * Match will attempt to match the given pathname against this route while
   * also taking into account the referrer information.
   *
   * @param pathname The pathname to match against.
   * @param options The options to use when matching.
   * @returns The match result, or `null` if there was no match.
   */ match(pathname, options) {
        // This is like the parent `match` method but instead this injects the
        // additional `options` into the
        const result = this.test(pathname, options);
        if (!result) return null;
        return {
            definition: this.definition,
            params: result.params
        };
    }
    /**
   * Test will attempt to match the given pathname against this route while
   * also taking into account the referrer information.
   *
   * @param pathname The pathname to match against.
   * @param options The options to use when matching.
   * @returns The match result, or `null` if there was no match.
   */ test(pathname, options) {
        // If this route does not have referrer information, then we can't match.
        if (!(options == null ? void 0 : options.referrer)) {
            return null;
        }
        // If the intercepting route match does not match, then this route does not
        // match.
        if (!this.interceptingRouteMatcher.test(options.referrer)) {
            return null;
        }
        // Perform the underlying test with the intercepted route definition.
        return super.test(pathname);
    }
}

//# sourceMappingURL=app-intercepting-route-matcher.js.map